# Signalab

A simple, flexible, and efficient backtesting framework for trading strategies.

---

<sub>🚀 Project starter provided by [Cookie Pyrate](https://github.com/gvieralopez/cookie-pyrate)</sub>
